@@ -1,4 +1,4 @@
-// $Id: Cxx.cc,v 1.102 2003/05/17 18:22:09 christof Exp $
+// $Id: Cxx.cc,v 1.115 2004/05/03 15:26:46 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -26,10 +26,6 @@
 
 // for some accesses
 #include <time.h>
-#ifndef __MINGW32__
-#include <pwd.h>
-#include <sys/utsname.h>
-#endif
 #include <unistd.h>
 #include <sys/stat.h>
 
@@ -37,6 +33,11 @@
 
 WidgetMap_t WidgetMap;
 
+static std::string ac_def_comment(const std::string &x)
+{  if (Configuration.autoconf_version<Pkg_Version(2,50,0)) return "";
+   return ",\n\t\t["+x+"]";
+}
+
 Cxx::Cxx(Tag *tp) 
 	:top(tp), current_set(0)
 {}
@@ -157,8 +158,12 @@ void Cxx::WriteTags()
             WriteHeader(todo,File_TODO);
          }
          
-         acconfig.open(FileNameByType(File_ACCONFIG_H));
-	 WriteHeader(acconfig,File_ACCONFIG_H);
+         if (Configuration.autoconf_version<Pkg_Version(2,50,0)
+         	// gnome1 does not work with autoheader2.59
+         	|| (Configuration.gnome_support && Configuration.Gtkmm1()))
+         {  acconfig.open(FileNameByType(File_ACCONFIG_H));
+	    WriteHeader(acconfig,File_ACCONFIG_H);
+	 }
          
          if (Configuration.gettext_support)
          {  po_cl.open(FileNameByType(File_po_ChangeLog,0),std::ios::app);
@@ -188,7 +193,8 @@ void Cxx::WriteTags()
          WriteFooter(changelog,File_ChangeLog); changelog.close();
          WriteFooter(news,File_NEWS); news.close();
          WriteFooter(todo,File_TODO); todo.close();
-         WriteFooter(acconfig,File_TODO); acconfig.close();
+         if (Configuration.autoconf_version<Pkg_Version(2,50,0))
+         {  WriteFooter(acconfig,File_TODO); acconfig.close(); }
          
          if (Configuration.gettext_support)
          {  WriteFooter(po_cl,File_po_ChangeLog); po_cl.close();
@@ -206,6 +212,11 @@ void Cxx::WriteTags(Tag &t)
    }
    else
    {  ApplyPreferences(t); // XXX better scanning!
+      if (Configuration.only_private_widgets) 
+      {  Configuration.lookup_table_compat=true;
+         ApplyPreferences(t);
+         Configuration.only_private_widgets=true; // re-set it
+      }
 //      if (Configuration.debug) w.debug();
       Cxx_Fileset fs(t,*this);
       fs.WriteFiles(true);
@@ -285,9 +296,13 @@ void Cxx::WriteHeader(CxxFile &f,File_type tp)
 	       // ourself.
 	       f.Include("bonobomm/widgets/wrap_init.h");
 	    }
-	    if (Configuration.gettext_support)
-	       f.Include("libgnome/gnome-i18n.h");
 	 }
+	 if (Configuration.gettext_source==Configuration::GT_GNOME)
+	       f.Include("libgnome/gnome-i18n.h");
+	 else if (Configuration.gettext_source==Configuration::GT_GLIB)
+	       f.Include("glib/gi18n.h");
+	 else if (Configuration.gettext_source==Configuration::GT_GNU)
+	       f.Include("libintl.h");
    	 f << '\n';
    	 break;
       case File_ACCONFIG_H:
@@ -354,12 +369,22 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
          break;
       case File_CONFIGURE_IN:
       	WriteCreation(f,tp);
-   	   f << "\n"
-		"AC_INIT("<< (Configuration.source_directory.c_str()+1)
+   	   f << "\n";
+	// or later? or automake dependant?
+	if (Configuration.autoconf_version>=Pkg_Version(2,50,0))
+	{  f << "AC_PREREQ(2.50)\n"
+		"AC_INIT("<< Configuration.main_filename <<", 0.0,["
+			<< Configuration.author_email << "])\n"
+		"AM_INIT_AUTOMAKE\n"
+	        "AC_CONFIG_HEADERS(config.h)\n";
+	}
+	else 
+	{  f << "AC_INIT("<< (Configuration.source_directory.c_str()+1)
 		<< '/' << Configuration.main_filename <<".cc)\n"
-		"AM_INIT_AUTOMAKE("<< Configuration.main_filename <<", 0.0)\n"
-	        "AM_CONFIG_HEADER(config.h)\n"
-	        "\n";
+		"AM_INIT_AUTOMAKE("<< Configuration.main_filename <<", 0.0)\n";
+	   f << "AM_CONFIG_HEADER(config.h)\n";
+	}
+	f << "\n";
 	if (Configuration.gnome_support && GNOME1) 
 	{    f << "dnl Pick up the Gnome macros.\n"
 		 "AM_ACLOCAL_INCLUDE(macros)\n"
@@ -389,30 +414,43 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
 	   // as seen in glade-2
 	   f << "GETTEXT_PACKAGE=" << Configuration.main_filename << '\n';
 	   f << "AC_SUBST(GETTEXT_PACKAGE)\n"
-	   	"AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,\"$GETTEXT_PACKAGE\")\n\n";
+	   	"AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,\"$GETTEXT_PACKAGE\""<<
+	   	ac_def_comment("the gettext domain")<<")\n\n";
 	   f << "dnl Add the languages which your application supports here.\n"
 	   	"ALL_LINGUAS=\"\"\n";
-	   f << "AM_";
-	   if (Configuration.gtk_version<Pkg_Version(1,3,0))
-	      f << (!Configuration.gnome_support?"GNU":"GNOME");
-	   else // glib 2.0
-	      f << /*"GLIB_"*/ "GNU";
-	   f <<"_GETTEXT\n"
-	   	"\n";
+	   if (Configuration.gettext_source==Configuration.GT_GNOME)
+	      f << "AM_GNOME_GETTEXT\n";
+	   else if (Configuration.gettext_source==Configuration.GT_GLIB)
+	      f << "AM_GLIB_GNU_GETTEXT\n";
+	   else // GT_GNU
+	   {  f << "AM_GNU_GETTEXT_VERSION("<<Configuration.gettext_version<<")\n"
+	   	<< "AM_GNU_GETTEXT";
+	      if (!Configuration.ship_libintl) f << "([external])";
+	      f << "\n";
+	   }
+	   f <<	"\n";
 		// is this correct?
 		// only needed for gnome 1.x?
            f << "dnl Set PACKAGE_LOCALE_DIR in config.h.\n"
    		"if test \"x${prefix}\" = \"xNONE\"; then\n"
-   		"  AC_DEFINE_UNQUOTED(PACKAGE_LOCALE_DIR, \"${ac_default_prefix}/${DATADIRNAME}/locale\")\n"
+   		"  AC_DEFINE_UNQUOTED(PACKAGE_LOCALE_DIR, \"${ac_default_prefix}/${DATADIRNAME}/locale\""<<
+   			ac_def_comment("the location of locale files")<<")\n"
    		"else\n"
-   		"  AC_DEFINE_UNQUOTED(PACKAGE_LOCALE_DIR, \"${prefix}/${DATADIRNAME}/locale\")\n"
+   		"  AC_DEFINE_UNQUOTED(PACKAGE_LOCALE_DIR, \"${prefix}/${DATADIRNAME}/locale\""<<
+   			ac_def_comment("the location of locale files")<<")\n"
    		"fi\n"
 		"\n";
         }
 	   f << "AC_LANG_CPLUSPLUS\n"
 		"\n";
 	if (!Configuration.gnome_support) // we trust ...
-	{  if (GTKMM2)
+	{  if (Configuration.gtkmm_version>=Pkg_Version(2,3,0))
+	      f << "PKG_CHECK_MODULES(GTKMM,[gtkmm-2.4 >= "
+	      	<< Configuration.gtkmm_version << "],,\n"
+	      		"\t[PKG_CHECK_MODULES(GTKMM,[gtkmm-2.0 >= 2.0.0])])\n"
+	      	"AC_SUBST(GTKMM_CFLAGS)\n"
+	      	"AC_SUBST(GTKMM_LIBS)\n";
+	   else if (GTKMM2)
 	      f << "PKG_CHECK_MODULES(GTKMM,[gtkmm-2.0 >= "
 	      	<< Configuration.gtkmm_version << "])\n"
 	      	"AC_SUBST(GTKMM_CFLAGS)\n"
@@ -454,19 +492,37 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
 		"AC_SUBST(PACKAGE_PIXMAPS_DIR)\n"
 #endif
 	 f << "AC_OUTPUT(Makefile " << (Configuration.source_directory.c_str()+1) << "/Makefile ";
-	 if (!GTKMM2)
-	 {  if (Configuration.gettext_support && !Configuration.gnome_support)
+	 if (Configuration.ship_libintl)
 	 	// glade does this too ..., but does not work on debian
 	       f << "intl/Makefile ";
-	    if (Configuration.gettext_support)
-	       f << " po/Makefile.in ";
-	    if (Configuration.gnome_support)
+	 if (!GTKMM2)
+	 {  if (Configuration.gnome_support)
 	       f << " macros/Makefile";
 	 }
 	 f << ")\n";
          break;
       case File_AUTOGEN_SH:
-	if (Configuration.gnome_support)
+        if (Configuration.use_autoreconf)
+        {  // I finally gave up and resorted to doing by hand ...
+           f << "#!/bin/sh\n"
+		 "# Run this to generate all the initial makefiles, etc.\n"
+		 "\n"
+		 "# if this does not work for you try glade-- --no-autoreconf\n"
+		 "libtoolize --force\n";
+	   if (Configuration.gettext_support)
+	      f << "gettextize\n"
+	      		// the following lines gave me an initial
+	      		// working gettext environment
+	      		"# if you know a better way, tell me\n"
+			"if test ! -e po/Makevars\n"
+			"then cp po/Makevars.template po/Makevars\n"
+			"fi\n"
+			"if test ! -e po/LINGUAS\n"
+			"then touch po/LINGUAS\n"
+			"fi\n";		 
+	  f << "autoreconf --force --install\n";
+        }
+	else if (Configuration.gnome_support)
 	{  if (GNOME2)
 	   {  f << "#!/bin/sh\n"
 		 "# Run this to generate all the initial makefiles, etc.\n"
@@ -550,22 +606,56 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
 		"HAVE_GNU_MAKE=`$MAKE --version|grep -c \"Free Software Foundation\"`\n"
 		"\n"
 		"if test \"$HAVE_GNU_MAKE\" != \"1\"; then \n"
-		"echo Using non GNU Make at $MAKE\n"
+		"echo Only non-GNU make found: $MAKE\n"
 		"else\n"
-		"echo Found GNU Make at $MAKE ... good.\n"
+		"echo `$MAKE --version | head -1` found\n"
 		"fi\n"
+		"\n";
+	 if (Configuration.autoconf_version>=Pkg_Version(2,50,0))
+	 // I assume that a newer automake will be good as well
+	 {  f << "if which autoconf2.50 >/dev/null 2>&1\n"
+		"then AC_POSTFIX=2.50\n"
+		"elif which autoconf >/dev/null 2>&1\n"
+		"then AC_POSTFIX=\"\"\n"
+		"else \n"
+		"  echo 'you need autoconfig (2.58+ recommended) to generate the Makefile'\n"
+		"  exit 1\n"
+		"fi\n"
+		"echo `autoconf$AC_POSTFIX --version | head -1` found\n"
 		"\n"
-		"echo This script runs configure and make...\n"
-		"echo You did remember necessary arguments for configure, right?\n"
-		"\n"
-		"if test ! -x `which aclocal`  \n"
+		"if which automake-1.9 >/dev/null 2>&1\n"
+		"then AM_POSTFIX=-1.9\n"
+		"elif which automake-1.8 >/dev/null 2>&1\n"
+		"then AM_POSTFIX=-1.8\n"
+		"elif which automake-1.7 >/dev/null 2>&1\n"
+		"then AM_POSTFIX=-1.7\n"
+		"elif which automake-1.6 >/dev/null 2>&1\n"
+		"then AM_POSTFIX=-1.6\n"
+		"elif which automake >/dev/null 2>&1\n"
+		"then AM_POSTFIX=\"\"\n"
+		"else\n"
+		"  echo 'you need automake (1.8.3+ recommended) to generate the Makefile'\n"
+		"  exit 1\n"
+		"fi\n"
+		"echo `automake$AM_POSTFIX --version | head -1` found\n"
+		"\n";
+	 }
+	 else 
+	   f << "if test ! -x `which aclocal`\n"
 		"then echo you need autoconfig and automake to generate the Makefile\n"
 		"fi\n"
-		"if test ! -x `which automake`  \n"
+		"if test ! -x `which automake`\n"
 		"then echo you need automake to generate the Makefile\n"
 		"fi\n"
-		"\n"
-		"libtoolize --force --copy\n";
+		"\n";
+		
+	  f << "echo This script runs configure and make...\n"
+		"echo You did remember necessary arguments for configure, right?\n"
+		"\n";
+           f << "# autoreconf$AC_POSTFIX -fim _might_ do the trick, too.\n"
+           	"#  chose to your taste\n";
+	   f << "aclocal$AM_POSTFIX\n";
+	  f <<	"libtoolize --force --copy\n";
 	   if (Configuration.gettext_support)
 	      f << "gettextize\n"
 	      		// the following lines gave me an initial
@@ -576,10 +666,9 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
 			"if test ! -e po/LINGUAS\n"
 			"then touch po/LINGUAS\n"
 			"fi\n";
-	   f << "autoheader\n";
-	   f << "aclocal\n";
-	   f << "automake --add-missing --copy --gnu\n"
-		"autoconf\n"
+	   f << "autoheader$AC_POSTFIX\n";
+	   f << "automake$AM_POSTFIX --add-missing --copy --gnu\n"
+		"autoconf$AC_POSTFIX\n"
 		"./configure $* && $MAKE\n";
 	}
          break;
@@ -597,12 +686,12 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
         }
         f << "\nSUBDIRS = "; 
         if (Configuration.gettext_support) 
-              f << "po "; // does gnome need intl? glade adds it ...
+              f << "po ";
+        if (Configuration.ship_libintl)
+              f << "intl ";
         if (!GTKMM2)
         {  if (Configuration.gnome_support)
               f << "macros ";
-           if (!Configuration.gnome_support && Configuration.gettext_support) 
-              f << "intl "; // does gnome really need intl?
         }
         f << (Configuration.source_directory.c_str()+1) << ' ';
         f << "\n"
@@ -618,28 +707,11 @@ void Cxx::WriteHeader(SystemFile &f,File_type tp)
         	"and the README file has not been edited since then ;-).\n";
         break;
       case File_AUTHORS:
-      {
-#ifndef __MINGW32__      
-        struct passwd *pwd=getpwuid(getuid());
-        struct utsname uts;
-        if (uname(&uts)) 
-        {  strcpy(uts.nodename,"(unknown)"); 
-#ifdef HAS_DOMAINNAME   
-           strcpy(uts.domainname,"(unknown)");
-#endif      
-        }
-#ifdef HAS_REAL_NAME
-	f << (pwd?pwd->HAS_REAL_NAME:"") << " <";
-#endif        
-        f << (pwd?pwd->pw_name:"(unknown)") << '@'
-          << uts.nodename;
-#ifdef HAS_DOMAINNAME     
-        f << '.' << uts.domainname ;
-#endif     
-#ifdef HAS_REAL_NAME
-	f << '>';
-#endif
-#endif
+      { if (!Configuration.author_name.empty())
+           f << Configuration.author_name << " <" 
+             << Configuration.author_email << ">";
+        else if (!Configuration.author_email.empty())
+           f << Configuration.author_email;
         f << '\n';
         break;
       }
@@ -819,22 +891,8 @@ void Cxx::WriteCreation(SystemFile &f,File_type tp)
    f.OStream().width(2);
    f << tm->tm_sec << ' ' << tzname[tm->tm_isdst];
    f.OStream().fill(oldfill); f.OStream().width(oldwidth);
-#ifndef __MINGW32__   
-   struct passwd *pwd=getpwuid(getuid());
-   struct utsname uts;
-   if (uname(&uts)) 
-   {  strcpy(uts.nodename,"(unknown)"); 
-#ifdef HAS_DOMAINNAME   
-      strcpy(uts.domainname,"(unknown)");
-#endif      
-   }
-   f << " by " << (pwd?pwd->pw_name:"(unknown)") << '@'
-     << uts.nodename 
-#ifdef HAS_DOMAINNAME     
-     << '.' << uts.domainname 
-#endif
-	;
-#endif
+   if (!Configuration.author_email.empty())
+      f << " by " << Configuration.author_email;
    f << '\n';
    f << comment << " using "GLADEMM_NAME"\n";
 }
