@@ -1,4 +1,4 @@
-// $Id: Cxx_Fileset.cc,v 1.88 2003/06/18 10:35:48 christof Exp $
+// $Id: Cxx_Fileset.cc,v 1.92 2004/05/07 07:04:47 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -354,6 +354,21 @@ void Cxx_Fileset::WriteClasses(const Widget &w)
    }
    ConnectSignalHandler(top_wr,w,w,inst);
 
+   // Write out grab_default(), if any
+   for (Widget::const_contained_iterator i=w.begin_contained(Internal_Both);
+	i!=w.end_contained();++i)
+   {  Widget w2(*i);
+      if (w2.getBoolProperty("has_default") )
+      {  const Widget WriterWidget(*(i.getWriterTag()));
+         const WriterBase &ww_wr(LookupWriter(WriterWidget));
+         std::string instance(ww_wr.Instance(WriterWidget,w2,i.getSWType()));
+         if (instance.empty()) 
+            continue; // can't connect this widget
+	 gc.Statement() << instance << "grab_default()";
+	 break;
+      }
+   }
+
    // add them to the map
    if (Configuration.lookup_table)
    {  if (w.getProperty("cxx_visibility","private")=="public") 
@@ -452,6 +467,12 @@ void Cxx_Fileset::WriteHeader(WidgetFile &f,File_type tp)
 // XXX f.type() or tp?
       	      "\n#ifndef "<<Configuration.FileDefine(f.widgetName(),f.type())<<"\n" 
       	      "#  define "<<Configuration.FileDefine(f.widgetName(),f.type())<<"\n\n";
+      	 if (Configuration.only_private_widgets)
+      	 {  f << "// Since all your widgets were private I made them all public.\n"
+      	         "// To differentiate between accessable (e.g. entries, output labels)\n"
+      	         "// and unaccessible widgets (e.g. static labels, containers)\n"
+      	         "// you should use the 'visibility' property (only visible in C++ mode)\n\n";
+      	 }
       	 if (Configuration.has_accelerators)
       	 {  std::string agtype=WriterBase::GtkPrefix()+"AccelGroup *";
       	    if (GTKMM2) agtype="Glib::RefPtr<Gtk::AccelGroup> ";
@@ -525,6 +546,18 @@ void Cxx_Fileset::WriteHeader(WidgetFile &f,File_type tp)
                   "#endif\n";
 	    }
 	 }
+	 if (Configuration.gtkmm_version>=Pkg_Version(2,3,0) 
+	 	&& !Configuration.drop_gtkmm22_support)
+	 {  f.Include("gtkmmconfig.h");
+	    f.CppIf() << "GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2";
+	    f.Include("sigc++/compatibility.h");
+	    f.DefineName("GMM_GTKMM_22_24(a,b)");
+	    f.DefineBody("b");
+	    f.CppElse() << "gtkmm 2.2";
+	    f.DefineName("GMM_GTKMM_22_24(a,b)");
+	    f.DefineBody("a");
+	    f.EndIf();
+	 }
          break;
       case File_FOO_CC:
          Cxx::WriteCreation(f,tp);
