@@ -1,4 +1,4 @@
-// $Id: Cxx_Fs_Signal.cc,v 1.30 2003/04/04 09:23:47 christof Exp $
+// $Id: Cxx_Fs_Signal.cc,v 1.34 2004/05/10 13:18:00 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -109,10 +109,18 @@ void Cxx_Fileset::DeclareSignalHandler(const WriterBase &wr, const Widget &w, co
       std::string rettype("void");
       std::string scope;
       const std::string args(wr.SignalHandlerArgs(w,signal,rettype,scope));
+      std::string args22(args);
       const std::string user_data(i->hasGladeAttr("data")
       		?UserDataDeclaration(i->getGladeAttr("data")):std::string());
       const std::string allargs(arg_concat(args,user_data));
       
+      if (GTKMM24)
+      {  Pkg_Version help=Configuration.gtkmm_version;
+         Configuration.gtkmm_version=Pkg_Version(2,2,0);
+         args22=wr.SignalHandlerArgs(w,signal,rettype,scope);
+         Configuration.gtkmm_version=help;
+      }
+      
 // I can't add this member declaration, yet 
 // (involves second tree scan (after registering) and adding 
 //  cross signal tags)
@@ -148,11 +156,22 @@ void Cxx_Fileset::DeclareSignalHandler(const WriterBase &wr, const Widget &w, co
       if (ProcedureDeclared(handlername+allargs+(emit_virtual?"V":" ")))
          continue;
       if ((GTKMM2 || signal!="switch_page") && !Configuration.non_virtual_callbacks && emit_virtual)
-      {  gh.Private().Declaration() << "virtual ";
+      {  gh.Private();
+         if (args!=args22) WriterBase::If24(gh);
+         gh.Declaration() << "virtual ";
          gh.Funct_ReturnType(rettype).FunctionName(handlername)
          	.FunctionArg(allargs).FunctionEndArgs();
          gh.Assignment("0");
          gh.EndLine();
+         if (args!=args22)
+         {  gh.CppElse();
+            gh.Declaration() << "virtual ";
+            gh.Funct_ReturnType(rettype).FunctionName(handlername)
+            	.FunctionArg(arg_concat(args22,user_data)).FunctionEndArgs();
+            gh.Assignment("0");
+            gh.EndLine();
+            gh.EndIf();
+         }
       }
       else if (!emit_virtual)
       {  h.Private().Declaration().Funct_ReturnType(rettype)
@@ -164,25 +183,28 @@ void Cxx_Fileset::DeclareSignalHandler(const WriterBase &wr, const Widget &w, co
 }
 
 void Cxx_Fileset::ConnectSignalHandler(const WriterBase &wr, const Widget &w, const Widget &top, const std::string &_instance)
-{  std::string instance(_instance); // we might need to modify it (see HACK)
-   for (Widget::const_iterator i=w.get_Signals();i!=w.end();++i)
-   {  std::string signal=i->getGladeAttr("name","");
+{  for (Widget::const_iterator i=w.get_Signals();i!=w.end();++i)
+   {  std::string instance(_instance); // we might need to modify it (see HACK)
+      std::string signal=i->getGladeAttr("name","");
       std::string handlername=i->getGladeAttr("handler","unknown");
       bool after=i->getGladeBoolAttr("after");
       bool non_virtual_callback=Configuration.non_virtual_callbacks;
+      bool is_proxy=wr.isProxySignal(w,signal,after);
       
       if (!non_virtual_callback && GTKMM1 && signal=="switch_page")
          non_virtual_callback=true;
 // OPTIONMENU HACK BEGINS
       if (signal=="deactivate" && wr.TypeName(w)==(wr.GtkPrefix()+"OptionMenu"))
          instance+="get_menu()->";
+      else if (signal=="changed" && wr.TypeName(w)==(wr.GtkPrefix()+"TextView"))
+         instance+="get_buffer()->";
 // OPTIONMENU HACK ENDS
 
       gc.Statement() << instance;
       if (GTKMM2) gc << "signal_";
       gc << Configuration.CName(signal);
       if (GTKMM2) gc << "()";
-      gc << ".connect" << (after && GTKMM1?"_after":"") << "(";
+      gc << ".connect" << (after && GTKMM1 && is_proxy?"_after":"") << "(";
       // dynamic cast<X>(y) ?
       if (i->hasGladeAttr("data"))
       {  gc << "SigC::bind(";
@@ -260,7 +282,10 @@ void Cxx_Fileset::ConnectSignalHandler(const WriterBase &wr, const Widget &w, co
       if (i->hasGladeAttr("data"))
       {  gc << ", " << UserDataPassing(i->getGladeAttr("data")) << ')';
       }
-      if (GTKMM2 && after) gc << ", true";
+      if (GTKMM2 && is_proxy)
+      {  if (after) gc << ", true"; // now the default
+         else gc << ", false";
+      }
       gc << ')';
       gc.EndLine();
    }
