@@ -1,4 +1,4 @@
-// $Id: CxxFile.cc,v 1.28 2003/05/19 08:51:25 christof Exp $
+// $Id: CxxFile.cc,v 1.29 2004/05/07 06:53:14 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -589,12 +589,24 @@ CxxFile &CxxFile::CppIf(void)
    return *this;
 }
 
+CxxFile &CxxFile::CppElif(void)
+{  NewLine().NoIndent() << "#elif ";
+   push(ctx_CppIf);
+   return *this;
+}
+
 CxxFile &CxxFile::EndIf(void)
 {  NewLine().NoIndent() << "#endif //";
    push(ctx_ShortComment);
    return *this;
 }
 
+CxxFile &CxxFile::CppElse(void)
+{  NewLine().NoIndent() << "#else //";
+   push(ctx_ShortComment);
+   return *this;
+}
+
 CxxFile &CxxFile::ShortComment(void)
 {  EndLine();
    Output() << "// ";
