@@ -1,4 +1,4 @@
-// $Id: SystemFile.cc,v 1.11 2002/06/03 21:26:31 christof Exp $
+// $Id: SystemFile.cc,v 1.12 2004/05/07 06:53:14 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1999 Adolf Petig GmbH. & Co. KG., written by Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -30,10 +30,7 @@ void SystemFile::close()
 {  
 // 2do: emit remembered lines?
    if (is_stringstream)
-   {  *streamptr.os << char(0);
-      if (remembered) remembered->remember(mystage,streamptr.os->str());
-      streamptr.os->freeze(0);
-      streamptr.os->seekp(0,std::ios::beg);
+   {  if (remembered) remembered->remember(mystage,streamptr.os->str(true));
    }
    else if (streamptr.of) streamptr.of->close();
    remembered_lines.erase(remembered_lines.begin(),remembered_lines.end());
