@@ -1,4 +1,4 @@
-// $Id: glade--.cc,v 1.79 2003/05/17 18:22:09 christof Exp $
+// $Id: glade--.cc,v 1.90 2004/05/10 06:33:15 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2002 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -35,6 +35,11 @@
 #include <getopt.h>
 #endif
 
+#ifndef __MINGW32__
+#include <pwd.h>
+#include <sys/utsname.h>
+#endif
+
 struct Configuration Configuration;
 
 enum longopts { GTKVERSION=0x100, GTKMMVERSION, AUTOCONF,
@@ -42,7 +47,7 @@ enum longopts { GTKVERSION=0x100, GTKMMVERSION, AUTOCONF,
 	OM_CREATE_ENUMS, CASE_CONV, UPPERCASE_ENUMS, MIXEDCASE_DEFINES,
 	OM_NO_CREATE_ENUMS, AUTOMAKE15, EMBED_PICS, LOAD_PICS, BASE_CLASS,
 	SHOW_OPTIONS, NON_VIRTUAL_CALLBACKS, LOOKUP_TABLE, FLAG_GNOME2,
-	LIBGLADE_OPTION, IMAGE_PROVIDER };
+	LIBGLADE_OPTION, IMAGE_PROVIDER, NOAUTORECONF, AUTORECONF };
 
 const static struct option options[]=
 { { "directory",	required_argument, NULL, 'd' },
@@ -74,6 +79,8 @@ const static struct option options[]=
   { "uppercase-enums",	no_argument,	   NULL, UPPERCASE_ENUMS },
   { "mixedcase-defines", no_argument,	   NULL, MIXEDCASE_DEFINES },
   { "automake-1-5",	no_argument,	   NULL, AUTOMAKE15 },
+  { "no-autoreconf",	no_argument,	   NULL, NOAUTORECONF },
+  { "autoreconf",	no_argument,	   NULL, AUTORECONF },
   { "embed-images",	no_argument,	   NULL, EMBED_PICS },
   { "load-images",	no_argument,	   NULL, LOAD_PICS },
   { "baseclass",	no_argument,	   NULL, BASE_CLASS },
@@ -148,7 +155,11 @@ static bool CheckVersion(const std::string &cmd, Pkg_Version &v, Pkg_Version::So
 static void call_gtkmm_config()
 {  CheckVersion("pkg-config --version",Configuration.pc_version,Pkg_Version::Pkg_Config);
 
-   if (CheckVersion("automake-1.7 --version",Configuration.automake_version,Pkg_Version::MMVersion,true))
+   if (CheckVersion("automake-1.9 --version",Configuration.automake_version,Pkg_Version::MMVersion,true))
+      Configuration.automake_name="automake-1.9";
+   else if (CheckVersion("automake-1.8 --version",Configuration.automake_version,Pkg_Version::MMVersion,true))
+      Configuration.automake_name="automake-1.8";
+   else if (CheckVersion("automake-1.7 --version",Configuration.automake_version,Pkg_Version::MMVersion,true))
       Configuration.automake_name="automake-1.7";
    else if (CheckVersion("automake-1.6 --version",Configuration.automake_version,Pkg_Version::MMVersion,true))
       Configuration.automake_name="automake-1.6";
@@ -166,11 +177,17 @@ static void call_gtkmm_config()
    else if (CheckVersion("autoconf2.13 --version",Configuration.autoconf_version,Pkg_Version::MMVersion,true))
       Configuration.autoconf_name="autoconf2.13";
 
+//   if (Configuration.autoconf_version>=Pkg_Version(2,50,0))
+//      Configuration.use_autoreconf=true;
+   
+   CheckVersion("gettext --version",Configuration.gettext_version,Pkg_Version::MMVersion,true);
+
    // Pkgconfig checks (Gnome 2)
    if (Configuration.gnome2) {
       if (!!Configuration.pc_version) {
 	 CheckVersion("pkg-config --silence-errors --modversion gtk+-2.0",Configuration.gtk_version,Pkg_Version::Pkg_Config);
-	 CheckVersion("pkg-config --silence-errors --modversion gtkmm-2.0",Configuration.gtkmm_version,Pkg_Version::Pkg_Config);
+	 if (!CheckVersion("pkg-config --silence-errors --modversion gtkmm-2.4",Configuration.gtkmm_version,Pkg_Version::Pkg_Config))
+	    CheckVersion("pkg-config --silence-errors --modversion gtkmm-2.0",Configuration.gtkmm_version,Pkg_Version::Pkg_Config);
 	 CheckVersion("pkg-config --silence-errors --modversion libgnomemm-2.0",Configuration.libgnomemm_version,Pkg_Version::Pkg_Config);
 	 CheckVersion("pkg-config --silence-errors --modversion libgnomeuimm-2.0",Configuration.libgnomeuimm_version,Pkg_Version::Pkg_Config);
          CheckVersion("pkg-config --silence-errors --modversion libbonobomm-2.0",Configuration.libbonobomm_version,Pkg_Version::Pkg_Config);
@@ -230,7 +247,7 @@ static void ApplyProject(const Tag &t)
    // XXX make pixmaps directory relative to source
    if ((Configuration.pixmap_dir.empty() || Configuration.pixmap_dir[0]!='/'))
       // blind guess, but better than nothing
-   {  if (!Configuration.source_directory.empty() && Configuration.source_directory!=".")
+   {  if (Configuration.source_directory!="/" && Configuration.source_directory!="/.")
          Configuration.pixmap_dir_relative_to_src="../"+Configuration.pixmap_dir;
       else // src should be current (?)
          Configuration.pixmap_dir_relative_to_src=Configuration.pixmap_dir;
@@ -256,6 +273,7 @@ static void ApplyProject(const Tag &t)
          exit(2);
       }
    Widget::const_contained_iterator::init();
+   
 }
 
 struct xmloption
@@ -435,6 +453,10 @@ int main(int argc,char **argv)
       case AUTOMAKE15: if (Configuration.automake_version<Pkg_Version(1,5,0))
       	    Configuration.automake_version=Pkg_Version(1,5,0,Pkg_Version::Command_Line);
          break;
+      case NOAUTORECONF: Configuration.use_autoreconf=false;
+         break;
+      case AUTORECONF: Configuration.use_autoreconf=true;
+         break;
       case EMBED_PICS: Configuration.embed_images=true;
          break;
       case LOAD_PICS: Configuration.embed_images=false;
@@ -539,6 +561,23 @@ reopen:
 
    if (Configuration.debug) top.debug(depth);
    call_gtkmm_config();
+   
+   // Apply dependant preferences 
+   if (Configuration.gettext_support)
+   {  if (Configuration.gtk_version>=Pkg_Version(2,4,0)) 
+         Configuration.gettext_source=Configuration::GT_GLIB;
+      else if (Configuration.gnome_support) 
+         Configuration.gettext_source=Configuration::GT_GNOME;
+      else
+         Configuration.gettext_source=Configuration::GT_GNU;
+   }
+   if (Configuration.gettext_source==Configuration::GT_GNU 
+   		&& !Configuration.gettext_version)
+   {  std::cerr << "gettext not found, disabled\n";
+      Configuration.gettext_support=false;
+      Configuration.gettext_source=Configuration::GT_NONE;
+   }
+
    if (!!Configuration.pc_version) 
       std::cout << "Found pkg-config version " << Configuration.pc_version
       	 << '\n';
@@ -569,6 +608,26 @@ reopen:
       if (!Configuration.gnome_support) std::cout << ']';
    }
    std::cout << '\n';
+   if (!Configuration.no_autoconf)
+   { std::cout << "Using " << Configuration.autoconf_name << ' '
+   	<< Configuration.autoconf_version << ", "
+   	<< Configuration.automake_name << ' '
+   	<< Configuration.automake_version;
+     if (Configuration.gettext_source==Configuration::GT_GNU)
+     {  std::cout << ", gettext " << Configuration.gettext_version;
+     }
+     else if (Configuration.gettext_source==Configuration::GT_GNOME)
+     {  std::cout << ", gnome's gettext";
+     }
+     else if (Configuration.gettext_source==Configuration::GT_GLIB)
+     {  std::cout << ", glib's gettext";
+     }
+     std::cout << '\n';
+   }
+   if (Configuration.gnome_support && !Configuration.Gtkmm1())
+   {  std::cerr << "Gnome 2.x support is unmaintained - expect problems\n";
+   }
+#if 0   
    if (Configuration.gettext_support && !Configuration.gnome_support
    	&& Configuration.Gtkmm1())
    {  std::cout << "Gettext support is not yet implemented without gnome.\n"
@@ -576,6 +635,28 @@ reopen:
    	"Disabling gettext for now.\n";
       Configuration.gettext_support=false;
    }
+#endif
+#ifndef __MINGW32__   
+  {struct passwd *pwd=getpwuid(getuid());
+   struct utsname uts;
+   if (uname(&uts)) 
+   {  strcpy(uts.nodename,"(unknown)"); 
+#ifdef HAS_DOMAINNAME   
+      strcpy(uts.domainname,"(unknown)");
+#endif      
+   }
+   Configuration.author_email=std::string(pwd?pwd->pw_name:"(unknown)")
+   	+ "@" + uts.nodename
+#ifdef HAS_DOMAINNAME     
+        + "." + uts.domainname 
+#endif
+	;
+#ifdef HAS_REAL_NAME
+   Configuration.author_name= pwd->HAS_REAL_NAME;
+#endif
+  }
+#endif
+   
    // now the generated project rejects to compile
 //   if (Configuration.Gtkmm2())
 //      std::cout << "WARNING: THIS PROGRAM WILL CRASH IF COMPILED WITH G++ 2.9x!!!\n";
@@ -583,13 +664,13 @@ reopen:
    Cxx *cxx=new Cxx(&top);
    cxx->WriteTags();
    if (Configuration.only_private_widgets)
-      std::cerr << "WARNING: All your widgets are declared as private members, you won't be\n"
-         "\table to access them unless you raise the \"visibilty\" to at least \"protected\".\n";
+      std::cerr << "WARNING: All your widgets are declared as private members, so I made them all\n"
+         "\tpublic. Use \"visibilty\" to tell which widgets you need to access.\n";
    delete cxx;
    return 0;
   }
    catch (std::exception &e)
-   {  std::cerr << "Error loading .glade file, exiting.\n"; exit(1); }
+   {  std::cerr << "Error "<< e.what()<<" loading .glade file, exiting.\n"; exit(1); }
 }
 
 // ok, strictly this does not belong here ...
