@@ -1,4 +1,4 @@
-// $Id: sanity_checks.cc,v 1.4 2001/10/11 14:07:23 christof Exp $
+// $Id: sanity_checks.cc,v 1.6 2002/11/15 08:21:40 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *
@@ -34,3 +34,8 @@ int main()
 
 struct Configuration Configuration;
 
+// ok, strictly this does not belong here ...
+
+ostream &operator<<(ostream &o, const Pkg_Version &v)
+{  return o << v.mymajor << '.' << v.myminor << '.' << v.mymicro;
+}
