@@ -1,4 +1,4 @@
-// $Id: WriterBase.cc,v 1.70 2003/05/16 14:56:46 christof Exp $
+// $Id: WriterBase.cc,v 1.75 2004/06/14 10:38:30 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
  *
@@ -27,26 +27,91 @@ void WriterBase::GHInclude(const Widget &w, CxxFile &f) const
    if (w.getProperty("cxx_visibility","private")=="private" && CanBeManaged(w)
 	&& !w.getBoolProperty(CXX_SEPERATE_CLASS))
       return; // only a local ctor variable needed
+   Pkg_Version help=Configuration.gtkmm_version;
+   bool need_special=TwoFourDifferent(w);
+   if (f.ElementAlreadyThere(CxxFile::element_t(
+   			CxxFile::v_IncludeBracket,IncludeName(w))))
+   {  if (!GTKMM24 || !need_special) return;
+      Configuration.gtkmm_version=Pkg_Version(2,2,0);
+      bool ret=f.ElementAlreadyThere(CxxFile::element_t(
+   			CxxFile::v_IncludeBracket,IncludeName(w)));
+      Configuration.gtkmm_version=help;
+      if (ret) return;
+   }
+   if (need_special)
+   {  If24(f);
+      f.Include(IncludeName(w));
+      f.CppElse();
+      Configuration.gtkmm_version=Pkg_Version(2,2,0);
+   }
    f.Include(IncludeName(w));
+   if (need_special)
+   {  Configuration.gtkmm_version=help;
+      f.EndIf();
+   }
 }
 
 void WriterBase::GCInclude(const Widget &w, CxxFile &f) const
 {  if (w.getProperty("cxx_visibility","private")!="private" || !CanBeManaged(w)
 	|| w.getBoolProperty(CXX_SEPERATE_CLASS))
       return; // only a local ctor variable needed
+   Pkg_Version help=Configuration.gtkmm_version;
+   bool need_special=TwoFourDifferent(w);
+   if (f.ElementAlreadyThere(CxxFile::element_t(
+   			CxxFile::v_IncludeBracket,IncludeName(w))))
+   {  if (!GTKMM24 || !need_special) return;
+      Configuration.gtkmm_version=Pkg_Version(2,2,0);
+      bool ret=f.ElementAlreadyThere(CxxFile::element_t(
+   			CxxFile::v_IncludeBracket,IncludeName(w)));
+      Configuration.gtkmm_version=help;
+      if (ret) return;
+   }
+   if (need_special)
+   {  If24(f);
+      f.Include(IncludeName(w));
+      f.CppElse();
+      Configuration.gtkmm_version=Pkg_Version(2,2,0);
+   }
    f.Include(IncludeName(w));
+   if (need_special)
+   {  Configuration.gtkmm_version=help;
+      f.EndIf();
+   }
+}
+
+void /*WriterBase::*/Visibility(CxxFile &f, const std::string &visibility)
+{
+   if (visibility=="private") f.Private();
+   else if (visibility=="protected") f.Protected();
+   else if (visibility=="public") f.Public();
+}
+
+void WriterBase::MemberVariable(CxxFile &f, const std::string &visibility,
+                const std::string &type, const std::string &name)
+{
+   Visibility(f,visibility);
+   f.Declaration() << type << ' ' << name;
+   f.EndLine();
 }
 
 void WriterBase::GHDeclaration(const Widget &w, CxxFile &f) const 
 {  const std::string visibility(w.getProperty("cxx_visibility","private"));
    if (visibility=="private" && CanBeManaged(w))
       return; // only a local ctor variable needed
-   if (visibility=="private") f.Private();
-   else if (visibility=="protected") f.Protected();
-   else if (visibility=="public") f.Public();
-   f.Declaration() << "class " << TypeName(w) << ' ';
-   f << '*' << Configuration.InstanceName(w.Name());
-   f.EndLine();
+   bool need_special=TwoFourDifferent(w);
+   Pkg_Version help=Configuration.gtkmm_version;
+   if (need_special)
+   {  Visibility(f,visibility);
+      If24(f);
+      MemberVariable(f,visibility,"class "+TypeName(w)+" *",Configuration.InstanceName(w.Name()));
+      f.CppElse();
+      Configuration.gtkmm_version=Pkg_Version(2,2,0);
+   }
+   MemberVariable(f,visibility,"class "+TypeName(w)+" *",Configuration.InstanceName(w.Name()));
+   if (need_special)
+   {  Configuration.gtkmm_version=help;
+      f.EndIf();
+   }
 }
 
 void WriterBase::Configure(Widget const &, CxxFile &, const std::string &instance) const
@@ -85,7 +150,7 @@ void WriterBase::Derivation(const Widget &w, CxxFile &f) const
 {  f.Derivation() << "public " << TypeName(w);
 }
 
-void WriterBase::CreatePointer(const Widget &w, CxxFile &f) const
+void WriterBase::CreatePointer_base(const Widget &w, CxxFile &f) const
 {  if (w.getProperty("cxx_visibility","private")=="private" && CanBeManaged(w))
      f.Declaration() << TypeName(w) << " *";
    else 
@@ -103,6 +168,22 @@ void WriterBase::CreatePointer(const Widget &w, CxxFile &f) const
    CreatePointer_Toplevel(w,f);
 }
 
+void WriterBase::CreatePointer(const Widget &w, CxxFile &f) const
+{  Pkg_Version help=Configuration.gtkmm_version;
+   bool need_special=TwoFourDifferent(w);
+   if (need_special)
+   {  If24(f);
+      CreatePointer_base(w,f);
+      f.CppElse();
+      Configuration.gtkmm_version=Pkg_Version(2,2,0);
+   }
+   CreatePointer_base(w,f);
+   if (need_special)
+   {  Configuration.gtkmm_version=help;
+      f.EndIf();
+   }
+}
+
 void WriterBase::DestroyPointer(const Widget &w, CxxFile &f) const
 {  DestroyPointer_Toplevel(w,f);
    if (!w.getBoolProperty(CXX_IS_MANAGED))
@@ -380,3 +461,75 @@ void WriterBase::setTagProperty(Tag &t, const std::string &name, const std::stri
 #endif
 
 
+const std::string WriterBase::GtkPrefix()
+{
+	   if (Configuration.gtkmm_version>=Pkg_Version(1,1,5))
+	      return "Gtk::";
+	   return "Gtk_";
+}
+const std::string WriterBase::GnomePrefix()
+{  if (GNOME2)
+	      return "Gnome::";
+	   // FIXME: Surely we should test gnomemm, not gtkmm, here.
+	   // I don't know which gnomemm version corresponds to gtkmm 1.1.5
+	   // but does anybody still care about that old versions
+	   if (Configuration.gtkmm_version>=Pkg_Version(1,1,5))
+	      return "Gnome::";
+	   return "Gnome_";
+}
+const std::string WriterBase::GnomeUIPrefix()
+{  
+	   if (GNOME2)
+	      return "Gnome::UI::";
+	   return GnomePrefix();
+}
+const std::string WriterBase::BonoboPrefix()
+{
+	   if (GNOME2)
+	      return "Gnome::Bonobo::";
+	   return "Bonobo::";
+}
+const std::string WriterBase::BonoboUIPrefix()
+{
+	   if (GNOME2)
+	      return "Gnome::Bonobo::";
+	   return "Bonobo::";
+}
+	
+	// strange things ... do we really need these any longer ?
+const std::string WriterBase::instance(const Widget &w)
+{  // if (w.getBoolProperty(CXX_SEPERATE_CLASS)) return ""; /* this->"; */
+	   return Configuration.InstanceName(w.Name())+"->";
+}
+const std::string WriterBase::instance_pointer(const Widget &w)
+{  // if (w.getBoolProperty(CXX_SEPERATE_CLASS)) return "this";
+	   return Pointer(w);
+}
+const std::string WriterBase::instance_reference(const Widget &w)
+{  // if (w.getBoolProperty(CXX_SEPERATE_CLASS)) return "(*this)";
+	   return Reference(w);
+}
+const std::string WriterBase::gtk_object_pointer()
+{
+	   if (Configuration.gtkmm_version >= Pkg_Version(1,3,0))
+	      return "gobj()";
+	   return "gtkobj()";
+}
+const std::string WriterBase::gtk_wrapper()
+{
+	   if (Configuration.gtkmm_version >= Pkg_Version(1,3,0))
+	      return "Glib::wrap";
+	   return "Gtk::wrap";
+}
+
+const std::string WriterBase::GTKMM_22_24(const std::string &a,const std::string &b)
+{  if (Configuration.gtkmm_version >= Pkg_Version(2,4,0))
+      return "GMM_GTKMM_22_24("+a+","+b+")";
+   else
+      return a;
+}
+
+CxxFile &WriterBase::If24(CxxFile &f)
+{  f.CppIf() << "GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2";
+   return f;
+}
