@@ -1,4 +1,4 @@
-// $Id: box.cc,v 1.22 2001/10/11 14:07:24 christof Exp $
+// $Id: box.cc,v 1.30 2003/03/31 14:09:27 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -27,7 +27,7 @@ const std::string Gtk_Box::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Box::IncludeName(const Widget &w) const
-{  return "gtk--/box.h";
+{  return Configuration.GtkmmIncludePath()+"box.h";
 }
 
 Gtk_Box::Gtk_Box(bool base_class_init)
@@ -38,39 +38,46 @@ Gtk_Box::Gtk_Box(bool base_class_init)
 }
 
 void Gtk_Box::ConstructionArgs(const Widget &w, CxxFile &f) const
-{  f.FunctionArg() << PRINT_BOOL(w.getBool("homogeneous",homo_def));
-   f.FunctionArg() << w.getInt("spacing",spac_def);
+{  f.FunctionArg() << PRINT_BOOL(w.getBoolProperty("homogeneous",homo_def));
+   f.FunctionArg() << w.getIntProperty("spacing",spac_def);
 }
 
 bool Gtk_Box::NeedExplicitCtor(const Widget &w) const
-{  return w.getBool("homogeneous",homo_def)!=homo_def
-	|| w.getInt("spacing",spac_def)!=spac_def; }
+{  return w.getBoolProperty("homogeneous",homo_def)!=homo_def
+	|| w.getIntProperty("spacing",spac_def)!=spac_def; }
 
 
 void Gtk_Box::AddChild(const Widget &w,CxxFile &f,const std::string &instance) const
 {  const ChildParamList ch(w.get_Child_params());
-   bool pack_end(ch.getString("pack","GTK_PACK_START")=="GTK_PACK_END");
-   bool expand(ch.getBool("expand",true));
-   bool fill(ch.getBool("fill",true));
-   int padding(ch.getInt("padding",0));
-   if (expand && fill && !padding)
-      f.Statement() << instance 
+   bool pack_end(ch.getProperty("pack","GTK_PACK_START")=="GTK_PACK_END");
+   bool expand(ch.getBoolProperty("expand",true));
+   bool fill(ch.getBoolProperty("fill",true));
+   int padding(ch.getIntProperty("padding",0));
+
+   // this is for dialog (see there)
+   if (GTKMM2 && w.hasProperty("response_id")) return;
+   
+   f.Statement() << instance 
         << (pack_end?"pack_end":"pack_start")
-        << '(' << Reference(w) << ')';
-   else
-      f.Statement() << instance << (pack_end?"pack_end":"pack_start") 
-        << '(' << Reference(w) << ", " << PRINT_BOOL(expand) 
-        << ", " << PRINT_BOOL(fill) << ", " << padding << ')';
+        << '(' << Reference(w);
+   if (expand && fill && !padding) ;
+   else if (GTKMM1)
+      f << ", " << PRINT_BOOL(expand) << ", " << PRINT_BOOL(fill)
+      	 << ", " << padding;
+   else // GTKMM2
+   {  std::string AttachOptions;
+      if (!expand) AttachOptions="Gtk::PACK_SHRINK";
+      else if (fill) AttachOptions="Gtk::PACK_EXPAND_WIDGET";
+      else AttachOptions="Gtk::PACK_EXPAND_PADDING";
+      f << ", " << AttachOptions << ", " << padding;
+   }
+   f << ')';
 }
 
 void Gtk_Box::Configure(const Widget &w,CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   if (w.hasTag("child_name")) // our ctor was never called
-   {  bool homogeneous(w.getBool("homogeneous",homo_def));
-      if (homogeneous!=homo_def) 
-      	 f.Statement() << instance << "set_homogeneous(" << PRINT_BOOL(homogeneous) << ')';
-      int spacing(w.getInt("spacing",spac_def));
-      if (spacing!=spac_def) 
-         f.Statement() << instance << "set_spacing(" << spacing << ')';
+   if (!w.ChildName().empty()) // our ctor was never called
+   {  WriteBoolProperty(w,f,instance, "homogeneous");
+      WriteIntProperty(w,f,instance, "spacing");
    }
 }
