@@ -1,4 +1,4 @@
-// $Id: checkbutton.cc,v 1.20 2002/12/09 09:42:29 christof Exp $
+// $Id: checkbutton.cc,v 1.21 2004/05/12 10:17:07 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -24,10 +24,11 @@ typedef float gfloat;
 static Gtk_CheckButton Gtk_CheckButton(false);
 
 const std::string Gtk_CheckButton::TypeName(const Widget &w) const
-{  return GtkPrefix()+"CheckButton";
+{  return GtkPrefix()+"Check"+(IsToolItem(w)?"Tool":"")+"Button";
 }
 const std::string Gtk_CheckButton::IncludeName(const Widget &w) const
-{  return Configuration.GtkmmIncludePath()+"checkbutton.h";
+{  return Configuration.GtkmmIncludePath()+"check"
+	+(IsToolItem(w)?"tool":"")+"button.h";
 }
 Gtk_CheckButton::Gtk_CheckButton(bool base_class_init)
 {  if (!base_class_init) Writer["GtkCheckButton"]=this;
