@@ -1,4 +1,4 @@
-// $Id: clist.cc,v 1.28 2001/11/05 15:28:20 christof Exp $
+// $Id: clist.cc,v 1.37 2003/01/06 07:27:14 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -28,7 +28,7 @@ const std::string Gtk_CList::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_CList::IncludeName(const Widget &w) const
-{  return "gtk--/clist.h";
+{  return Configuration.GtkmmIncludePath()+"clist.h";
 }
 
 Gtk_CList::Gtk_CList(bool base_class_init)
@@ -36,19 +36,18 @@ Gtk_CList::Gtk_CList(bool base_class_init)
 }
 
 void Gtk_CList::ConstructionArgs(const Widget &w, CxxFile &f) const
-{  f.FunctionArg() << w.getInt("columns",3);
+{  f.FunctionArg() << w.getIntProperty("columns",3);
            // 2do: look for columns and pass them ???
 }
 
 void Gtk_CList::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   std::string selection_mode=w.getString("selection_mode","GTK_SELECTION_SINGLE");
-   bool show_titles=w.getBool("show_titles",true);
-   std::string shadow_type=w.getString("shadow_type","GTK_SHADOW_IN");
-   std::string hscrollbar_policy=w.getString("hscrollbar_policy","GTK_POLICY_AUTOMATIC");
-   std::string vscrollbar_policy=w.getString("vscrollbar_policy","GTK_POLICY_AUTOMATIC");
-   std::string column_widths=w.getString("column_widths","20");
+   std::string column_widths=w.getProperty("column_widths","20");
+#ifdef __MINGW32__   
+   char buffer[column_widths.size()+1];
+#else
    char *buffer=(char*)alloca(column_widths.size()+1);
+#endif   
    memcpy(buffer,column_widths.c_str(),column_widths.size()+1);
    char *stringp=buffer;
    // 2do: Tooltips
@@ -58,11 +57,11 @@ void Gtk_CList::Configure(const Widget &w, CxxFile &f,const std::string &instanc
    {  char *token=strsep(&stringp,",");
       int column_width=!token?20:atoi(token);
       if ((*ch).Class()=="GtkLabel")
-      {  std::string label=(*ch).getString("label","");
-         if (label!="")
+      {  std::string label=(*ch).getProperty("label","");
+         if (!label.empty())
             f.Statement() << instance << "set_column_title(" << i << ", " 
               	<< Configuration.Translatable(label) << ')';
-         std::string justify=(*ch).getString("justify","GTK_JUSTIFY_LEFT");
+         std::string justify=(*ch).getProperty("justify","GTK_JUSTIFY_LEFT");
          if (justify!="GTK_JUSTIFY_LEFT")
             f.Statement() << instance << "set_column_justification(" << i << ", "
               << justify << ')';
@@ -72,15 +71,14 @@ void Gtk_CList::Configure(const Widget &w, CxxFile &f,const std::string &instanc
          std::cerr << "Gtk_CList::Configure: can't handle widget class "
               << (*ch).Class() << " as title\n";
    }
-   if (selection_mode!="GTK_SELECTION_SINGLE")
-      f.Statement() << instance << "set_selection_mode(" << selection_mode << ')';
-   if (show_titles)
-      f.Statement() << instance << "column_titles_show()";
+   WriteEnumPropertyNS(w,f,instance, "selection_mode");
+   WriteEnumPropertyNS(w,f,instance, "shadow_type");
+   WriteBoolProp_2Fun(w,f,instance, "show_titles", "column_titles_hide()", "column_titles_show()");
 }
 
 Subwidget Gtk_CList::IsSubwidget(const Widget &parent,const Widget &w2) const
 {  if (w2.ChildName()=="CList:title" && w2.Class()=="GtkLabel") return is_Subwidget_all;
-//	&& w2.getString("cxx_visibility","private")=="private") 
+//	&& w2.getProperty("cxx_visibility","private")=="private") 
    return not_Subwidget;
 }
 
@@ -88,8 +86,8 @@ Subwidget Gtk_CList::IsSubwidget(const Widget &parent,const Widget &w2) const
 bool Gtk_CList::SampleCode(CxxFile &f,const Widget &w,enum WriterType::CodePosition pos,const std::string misc)
 {  switch(pos)
    {  case WriterType::ContainingConstructor:
-         {  int cols=w.getInt("columns",3);
-            int width=w.getInt("width",100);
+         {  int cols=w.getIntProperty("columns",3);
+            int width=w.getIntProperty("width",100);
             if (!cols) return false;
             f << "\tconst gchar * const data_" << Configuration.InstanceName(w.Name()) << "[]=\n\t{ ";
             for (int i=0;i<cols;i++)
@@ -98,7 +96,7 @@ bool Gtk_CList::SampleCode(CxxFile &f,const Widget &w,enum WriterType::CodePosit
    	      << "\t" << Configuration.InstanceName(w.Name()) 
    	      << "->" << "append((gchar**)data_"
    	      << Configuration.InstanceName(w.Name()) << ");\n";
-   	    if (!w.hasTag("column_widths"))
+   	    if (!w.hasProperty("column_widths"))
    	       f << "\tfor (int i=0;i<" << cols << ";++i)\n\t\t"
    	         << Configuration.InstanceName(w.Name()) << "->" 
    	         << "set_column_width(i,"
@@ -111,8 +109,9 @@ bool Gtk_CList::SampleCode(CxxFile &f,const Widget &w,enum WriterType::CodePosit
 }
 #endif
 
-const std::string Gtk_CList::SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype) const
-{  if (signal=="select_row" || signal=="unselect_row") 
+const std::string Gtk_CList::SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype,std::string &scope) const
+{  scope=Gtk_CList::TypeName(w);
+   if (signal=="select_row" || signal=="unselect_row") 
       return "gint row, gint column, GdkEvent *event";
    else if (signal=="resize_column")
       return "gint column, gint width";
@@ -126,7 +125,7 @@ const std::string Gtk_CList::SignalHandlerArgs(const Widget &w,const std::string
       return "gint source_row, gint dest_row";
    else if (signal=="click_column")
       return "gint column";
-   return Parent::SignalHandlerArgs(w,signal,rettype);
+   return Parent::SignalHandlerArgs(w,signal,rettype,scope);
 }
 
 const std::string Gtk_CList::InternalInstance(const Widget &parent,const Widget &w2) const
@@ -134,3 +133,8 @@ const std::string Gtk_CList::InternalInstance(const Widget &parent,const Widget
 #warning Fixme for non standard column headers (internal widgets)
    return Parent::InternalInstance(parent,w2);
 }
+
+void Gtk_CList::ApplyPreferences(Tag &t) const
+{  if (GTKMM2) static_cast<GladeTag*>(&t)->setWidgetType("GtkTreeView");
+   Parent::ApplyPreferences(t);
+}
