@@ -1,4 +1,4 @@
-// $Id: combo.cc,v 1.31 2001/11/05 15:28:20 christof Exp $
+// $Id: combo.cc,v 1.42 2003/03/05 09:33:34 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -28,7 +28,7 @@ const std::string Gtk_Combo::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Combo::IncludeName(const Widget &w) const
-{  return "gtk--/combo.h";
+{  return Configuration.GtkmmIncludePath()+"combo.h";
 }
 
 Gtk_Combo::Gtk_Combo(bool base_class_init)
@@ -37,30 +37,40 @@ Gtk_Combo::Gtk_Combo(bool base_class_init)
 
 void Gtk_Combo::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
+
    // work around gtk bug (see gbwidget.c:3584)
    // "GTK BUG WORKAROUND - a combo should manage the size of its entry."
-   int width=w.getInt("width",-1);
-   int height=w.getInt("height",-1);
-   if (width!=-1 || height!=-1)
-   {  f.Statement() << instance << "get_entry()->set_usize(" 
-        << (width>16?width-16:-1) << ", " << height << ')';
+   if (GTKMM1) WriteIntIntProperty(w,f,instance+"get_entry()->", "width", "height", "usize");
+
+   WriteBoolProperty(w,f,instance, "case_sensitive");
+   WriteBoolProperty(w,f,instance, "use_arrows");
+   WriteBoolProperty(w,f,instance, "use_arrows_always");
+   
+   if (Configuration.glade2)
+   {  Widget::const_iterator i=w.begin();
+      for (;i!=w.end() && (*i).ChildName()!="list"; ++i);
+      if (i!=w.end() && ((*i).begin() != (*i).end()))
+      {  f.StartBlock().Declaration() << "const char * const items[]";
+         f.Assignment() << "{ ";
+         for (Widget::const_iterator j=(*i).begin();j!=(*i).end();++j)
+         {  assert((*j).Class()=="GtkListItem");
+            f << Configuration.static_Translatable((*j).getProperty("label")) 
+              << ", ";
+         }
+         f << "0 }";
+         f.Statement() << instance << "set_popdown_strings(items)";
+         f.EndBlock();
+      }
    }
-   bool case_sensitive=w.getBool("case_sensitive",true);
-   if (case_sensitive)
-      f.Statement() << instance << "set_case_sensitive(" << PRINT_BOOL(case_sensitive)
-        << ')';
-   bool use_arrows=w.getBool("use_arrows",true);
-   if (!use_arrows)
-      f.Statement() << instance << "set_use_arrows(" << PRINT_BOOL(use_arrows)
-        << ')';
-   bool use_arrows_always=w.getBool("use_arrows_always");
-   if (use_arrows_always)
-      f.Statement() << instance << "set_use_arrows_always(" << PRINT_BOOL(use_arrows_always) << ')';
    // items   
-   if (w.hasTag("items")) // append them
-   {  const std::string items(w.getString("items","<none>\n"));
+   else if (w.hasProperty("items")) // append them
+   {  const std::string items(w.getProperty("items","<none>\n"));
       const std::string name(Configuration.InstanceName(w.Name()));
+#ifdef __MINGW32__
+      char buffer[items.size()+1];
+#else      
       char *buffer=(char*)alloca(items.size()+1);
+#endif      
       memcpy(buffer,items.c_str(),items.size()+1);
       char *token,*stringp=buffer;
       f.StartBlock().Declaration() << "const char * const items[]";
@@ -78,20 +88,22 @@ void Gtk_Combo::Configure(const Widget &w, CxxFile &f,const std::string &instanc
       f.Statement() << instance << "set_popdown_strings(items)";
       f.EndBlock();
    }
-   // configure subwidget (entry) 
-   // - why is this needed (why not automatically?) CP 20001012
+   // now set the entry's text again (was lost by setting the popdown strings)
    for (Widget::const_iterator i=w.begin();i!=w.end();++i)
-   {  if ((*i).ChildName()=="GtkCombo:entry")
-         LookupWriter("GtkEntry").Configure((*i),f,instance+"get_entry()->");
+   {  if ((*i).ChildName()=="GtkCombo:entry" || (*i).ChildName()=="entry")
+         WriteTranslatableProperty((*i),f,instance+"get_entry()->", "text");
    }
 }
 
 Subwidget Gtk_Combo::IsSubwidget(const Widget &w,const Widget &ch) const
-{  if (ch.ChildName()=="GtkCombo:entry") return is_Subwidget_only;
+{  std::string cn=ch.ChildName();
+   if (cn=="GtkCombo:entry" || cn=="entry" || cn=="list") return is_Subwidget_all;
    return not_Subwidget;
 }
 
 const std::string Gtk_Combo::InternalInstance(const Widget &parent,const Widget &w2) const
-{  if (w2.ChildName()=="GtkCombo:entry") return "get_entry()->";
+{  std::string cn=w2.ChildName();
+   if (cn=="GtkCombo:entry" || cn=="entry") return "get_entry()->";
+   if (GTKMM1 && cn=="list") return "get_list()->";
    return Parent::InternalInstance(parent,w2);
 }
