@@ -1,4 +1,4 @@
-// $Id: custom.cc,v 1.11 2002/11/04 23:03:47 christof Exp $
+// $Id: custom.cc,v 1.14 2004/05/10 14:08:21 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -31,9 +31,10 @@ class Custom : public Gtk_Widget
 	virtual bool CanBeManaged(const Widget &w) const
 	{  return false; }
 	const std::string SignalHandlerArgs(const Widget &w,const std::string &signal,std::string &rettype,std::string &scope) const;
+	virtual bool isProxySignal(const Widget &w,std::string &method,bool after)const;
 };
 
-#include "label.hh"
+
 
 static Custom Custom;
 
@@ -113,3 +114,30 @@ const std::string Custom::SignalHandlerArgs(const Widget &w,const std::string &s
    }
    return Parent::SignalHandlerArgs(w,signal,rettype,scope);
 }
+
+bool Custom::isProxySignal(const Widget &w,std::string &method,bool after) const
+{  std::string scope=TypeName(w);
+  reloop:
+   if (Configuration.debug) 
+      std::cerr << "searching for signal " << method << " in " << scope << '\n';
+
+   if (Writer.find(scope)!=Writer.end())
+   {  bool is_signal=false;
+      if (isInternalMethod(w,method,"",scope,is_signal) && is_signal)
+         return LookupWriter(scope).isProxySignal(w,method,after);
+      // if signal is unknown default to non-proxy
+      return false;
+   }
+   else FOR_EACH_CONST_TAG(i,Configuration.custom_signal_args)
+   {  if (i->Type()!="class") continue;
+      if (i->getAttr("name")!=scope) continue;
+      FOR_EACH_CONST_TAG(j, *i)
+      {  if (j->Type()!="callback") continue;
+         if (j->getAttr("name")!=method) continue;
+         return j->getBoolAttr("proxy",false);
+      }
+      scope=i->getAttr("parent");
+      if (!scope.empty()) goto reloop;
+   }
+   return false;
+}
