@@ -1,6 +1,7 @@
-// $Id: default.cc,v 1.11 1998/09/24 13:19:44 cvs_christof Exp $
+// $Id: default.cc,v 1.11 2000/04/11 09:40:55 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
+ *  Copyright (C) 1999  Adolf Petig GmbH & Co. KG, written by Christof Petig
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,26 +18,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "writers.hh"
+#include "label.hh"
 
-void Default::Include(File &f,const Widget &w)
-{  f.include("gtk--/label.h");
+class Default : public Gtk_Label
+{public:
+	typedef Gtk_Label Parent;
+	Default();
+	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const;
+	virtual bool NeedExplicitCtor(const Widget &w) const
+	{  return true; }
+};
+
+static Default Default;
+
+Default::Default()
+{  Writer["Default"]=this;
 }
 
-void Default::Declare(File &f,const Widget &w)
-{  StandardWriter::Declare(f,w,"Gtk_Label");
-}
-
-void Default::Construct(File &f,const Widget &w,bool is_member)
-{  f << StandardWriter::ConstructName(f,w,is_member,"Gtk_Label");
-   f << "(\"" << f.CString(w.Name())
-           << "\")";
-}
-
-bool Default::NeedConstruct(const Widget &w,bool is_member)
-{  return true;
-}
-
-void Default::Customize(File &f,const Widget &w,const string instance)
-{  Gtk_Widget::Customize(f,w,instance);
+void Default::ConstructionArgs(const Widget &w, CxxFile &f) const
+{  f.FunctionArg() << Configuration.CString_WithQuotes(w.Name());
 }
