@@ -1,4 +1,4 @@
-// $Id: drawingarea.cc,v 1.12 2001/10/11 14:07:24 christof Exp $
+// $Id: drawingarea.cc,v 1.13 2002/05/14 08:25:44 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *
  *  Copyright (C) 1998  Joe Pfeiffer, pfeiffer@cs.nmsu.edu
@@ -28,7 +28,7 @@ const std::string Gtk_DrawingArea::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_DrawingArea::IncludeName(const Widget &w) const
-{  return "gtk--/drawingarea.h";
+{  return Configuration.GtkmmIncludePath()+"drawingarea.h";
 }
 
 Gtk_DrawingArea::Gtk_DrawingArea(bool base_class_init)
