@@ -1,4 +1,4 @@
-// $Id: editable.cc,v 1.8 2003/04/24 08:20:41 christof Exp $
+// $Id: editable.cc,v 1.9 2004/05/10 13:18:00 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -38,21 +38,6 @@ bool Gtk_Editable::isInternalMethod(const Widget &w,std::string &method,const st
 {  const char prefix[]="gtk_editable_";
    const int plen(sizeof(prefix)-1);
    if (method.substr(0,plen)==prefix) method=method.substr(plen);
-   if (((method=="changed" || method=="activate" || method=="cut_clipboard" 
-   		|| method=="copy_clipboard" || method=="paste_clipboard") 
-   			&& args.empty())
-        || (method=="insert_text" 
-        && matches("const gchar\\ *\\ \\_,\\ gint \\_,\\ gint\\ *\\ \\_",args))
-        || ((method=="delete_text" || method=="move_cursor" || method=="move_page")
-        		&& matches("gint \\_,\\ gint \\_",args))
-        || ((method=="move_word" || method=="move_to_row" || method=="move_to_column"
-        	|| method=="kill_char" || method=="kill_word" || method=="kill_line") 
-        		&& matches("gint \\_",args))
-        || (method=="set_editable" && matches("gboolean \\_",args)))
-   {  scope=Gtk_Widget::TypeName(w);
-      is_signal=true;
-      return true;
-   }
    if ((method=="select_region" && matches("gint\\ \\_,gint\\ \\_",args))
    	|| (method=="delete_selection" && args.empty()))
    {  scope=Gtk_Widget::TypeName(w);
