@@ -1,4 +1,4 @@
-// $Id: entry.cc,v 1.22 2001/10/11 14:07:24 christof Exp $
+// $Id: entry.cc,v 1.29 2003/04/24 08:20:41 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -27,7 +27,7 @@ const std::string Gtk_Entry::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Entry::IncludeName(const Widget &w) const
-{  return "gtk--/entry.h";
+{  return Configuration.GtkmmIncludePath()+"entry.h";
 }
 
 Gtk_Entry::Gtk_Entry(bool base_class_init)
@@ -36,25 +36,23 @@ Gtk_Entry::Gtk_Entry(bool base_class_init)
 
 void Gtk_Entry::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   int position(w.getInt("position",0));
-   if (position)
-      f.Statement() << instance << "set_position(" << position << ')';
-   bool text_visible(w.getBool("text_visible",true));
-   if (!text_visible)
-      f.Statement() << instance << "set_visibility(" << PRINT_BOOL(text_visible) << ')';
-   bool editable(w.getBool("editable",true));
-   f.Statement() << instance << "set_editable(" << PRINT_BOOL(editable) << ')';
-   // max length ... seems to be not in gtkmm
-   std::string text(w.getString("text",""));
-   if (text.size())
-      f.Statement() << instance << "set_text(" << Configuration.Translatable(text) << ')';
+   WriteIntProperty(w,f,instance, "position");
+   WriteBoolProperty(w,f,instance, "text_visible", false, "visibility");
+   WriteBoolProperty(w,f,instance, "visibility");
+   WriteBoolProperty(w,f,instance, "editable");
+   WriteIntProperty(w,f,instance, "max_length");
+   WriteTranslatableProperty(w,f,instance, "text");
+   WriteBoolProperty(w,f,instance, "has_frame");
+   // invisible_char is really difficult, we have to convert an UTF-8
+   // string to a gunichar, perhaps I do it later
+   WriteBoolProperty(w,f,instance, "activates_default");
+   WriteIntProperty(w,f,instance, "width_chars");
 }
 
 bool Gtk_Entry::isInternalMethod(const Widget &w,std::string &method,const std::string &args,std::string &scope,bool &is_signal) const
-{  const char *prefix("gtk_entry_");
+{  const char prefix[]="gtk_entry_";
    const int plen(sizeof(prefix)-1);
-   if (!strncmp(prefix,method.c_str(),plen))
-      method=std::string(method.c_str()+plen);
+   if (method.substr(0,plen)==prefix) method=method.substr(plen);
    if (((method=="set_text" || method=="set") && matches("const std::string &\\_",args))
 	|| (method=="append_text" && matches("const std::string &\\_",args))
 	|| (method=="prepend_text" && matches("const std::string &\\_",args))
