@@ -1,4 +1,4 @@
-// $Id: fixed.cc,v 1.22 2001/10/11 14:07:24 christof Exp $
+// $Id: fixed.cc,v 1.25 2002/10/23 06:30:39 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -42,7 +42,7 @@ const std::string Gtk_Fixed::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Fixed::IncludeName(const Widget &w) const
-{  return "gtk--/fixed.h";
+{  return Configuration.GtkmmIncludePath()+"fixed.h";
 }
 
 Gtk_Fixed::Gtk_Fixed()
@@ -50,8 +50,18 @@ Gtk_Fixed::Gtk_Fixed()
 }
 
 void Gtk_Fixed::AddChild(const Widget &w,CxxFile &f,const std::string &instance) const
-{  int x=w.getInt("x",0);
-   int y=w.getInt("y",0);
+{  int x=0;
+   int y=0;
+   
+   if (Configuration.glade2)
+   {  const ChildParamList ch(w.get_Child_params());
+      x=ch.getIntProperty("x",0);
+      y=ch.getIntProperty("y",0);
+   }
+   else
+   {  x=w.getIntProperty("x",0);
+      y=w.getIntProperty("y",0);
+   }
    f.Statement() << instance << "put" << '(' 
      << Reference(w) << ", " << x << ", " << y << ')';
 }
