@@ -1,4 +1,4 @@
-// $Id: image.cc,v 1.31 2003/04/23 12:34:41 christof Exp $
+// $Id: image.cc,v 1.33 2004/05/14 10:01:24 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -166,6 +166,9 @@ void Gtk_Image::CreatePointer(const Widget &w,CxxFile &f) const
       }
      }
       Parent::CreatePointer(w,f);
+      if (Configuration.image_provider.empty() && Configuration.embed_images
+      		&& xpm_ident.empty())
+         f.Statement() << "_" << instname << "_loader=Glib::RefPtr<Gdk::PixbufLoader>()";
    }
    else // can not work with 1.2 ???
    {  f.Declaration() << GtkPrefix()+"ImageLoaderData *_"<<
@@ -196,7 +199,11 @@ void Gtk_Image::EmbedImage(CxxFile &f,const std::string &pixbuf) const
    f << Configuration.CName(pixbuf) << "_data[]";
    f.Assignment().StartBlock().EndLine();
    {  std::ifstream is((Configuration.pixmap_dir+"/"+pixbuf).c_str());
-      while (is.good())
+      if (!is.good())
+      {  f << "\n#error error opening image " << Configuration.pixmap_dir 
+      		<< "/" <<pixbuf << "\n";
+      }
+      else while (is.good())
       {  /* unsigned ... hmmm g++3.1 does not like this ... */ char buf[16];
          is.read(buf,sizeof buf);
          size_t read=is.gcount();
