@@ -1,4 +1,4 @@
-// $Id: label.cc,v 1.19 2002/01/23 17:42:51 christof Exp $
+// $Id: label.cc,v 1.31 2003/04/24 08:20:41 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -27,7 +27,7 @@ const std::string Gtk_Label::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Label::IncludeName(const Widget &w) const
-{  return "gtk--/label.h";
+{  return Configuration.GtkmmIncludePath()+"label.h";
 }
 
 Gtk_Label::Gtk_Label(bool base_class_init)
@@ -35,17 +35,20 @@ Gtk_Label::Gtk_Label(bool base_class_init)
 }
 
 void Gtk_Label::ConstructionArgs(const Widget &w, CxxFile &f) const
-{  f.FunctionArg() << Configuration.Translatable(w.getString("label"));
+{  std::string label=w.getProperty("label");
+   f.FunctionArg() << Configuration.Translatable(label);
+   if (GTKMM2 && w.getBoolProperty("use_underline")
+  		&& ( label.find('_')!=std::string::npos ) )
+      f.FunctionArg() << "true";
 }
 
 bool Gtk_Label::NeedExplicitCtor(const Widget &w) const
-{  return w.hasTag("label"); }
+{  return w.hasProperty("label"); }
 
 bool Gtk_Label::isInternalMethod(const Widget &w,std::string &method,const std::string &args,std::string &scope,bool &is_signal) const
-{  const char *prefix("gtk_label_");
+{  const char prefix[]="gtk_label_";
    const int plen(sizeof(prefix)-1);
-   if (!strncmp(prefix,method.c_str(),plen))
-      method=std::string(method.c_str()+plen);
+   if (method.substr(0,plen)==prefix) method=method.substr(plen);
    if (((method=="set_text" || method=="set") && matches("const std::string &\\_",args))
         || (method=="parse_uline" && matches("const std::string &\\_",args))
         || (method=="set_pattern" && matches("const std::string &\\_",args))
@@ -60,10 +63,13 @@ bool Gtk_Label::isInternalMethod(const Widget &w,std::string &method,const std::
 void Gtk_Label::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
 
-   std::string justify=w.getString("justify","GTK_JUSTIFY_CENTER");
-   if (justify!="GTK_JUSTIFY_CENTER")
-      f.Statement() << instance << "set_justify(" << justify << ')';
-   bool wrap=w.getBool("wrap");
-   if (wrap)
-      f.Statement() << instance << "set_line_wrap(" << PRINT_BOOL(wrap) << ')';
+   WriteEnumPropertyNS(w,f,instance, "justify");
+   WriteBoolProperty(w,f,instance, "wrap", false, "line_wrap");
+   if (GTKMM2) WriteBoolProperty(w,f,instance, "use_markup", false, "use_markup");
+   if (GTKMM2) WriteBoolProperty(w,f,instance, "selectable", false);
+   if (GTKMM2 && w.hasProperty("mnemonic_widget")) 
+   {  f.Statement() << instance << "set_mnemonic_widget" << "(*"
+   		<< Configuration.InstanceName(w.getProperty("mnemonic_widget"))
+   		<< ')';
+   }
 }
