@@ -1,4 +1,4 @@
-// $Id: misc.cc,v 1.11 2001/10/11 14:07:24 christof Exp $
+// $Id: misc.cc,v 1.13 2002/06/15 13:22:14 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -22,11 +22,8 @@
 
 void Gtk_Misc::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   float xalign(w.getFloat("xalign",0.5));
-   float yalign(w.getFloat("yalign",0.5));
-   f.Statement() << instance << "set_alignment(" << xalign << ", " << yalign << ')';
-   float xpad(w.getInt("xpad",0));
-   float ypad(w.getInt("ypad",0));
-   f.Statement() << instance << "set_padding(" << xpad << ", " << ypad << ')';
+
+   WriteFloatFloatProperty(w,f,instance, "xalign", "yalign", "alignment", false, 0.5);
+   WriteIntIntProperty(w,f,instance, "xpad", "ypad", "padding");
 }
 
