@@ -1,4 +1,4 @@
-// $Id: paned.cc,v 1.24 2001/10/11 14:07:24 christof Exp $
+// $Id: paned.cc,v 1.33 2003/03/31 14:09:27 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -27,11 +27,13 @@ class Gtk_Paned : public Gtk_Container
 	virtual const std::string IncludeName(const Widget &w) const;
 	Gtk_Paned();
 	virtual void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
-	void Gtk_Paned::AddChildren(const Widget &w,CxxFile &f,const std::string &instance) const;
+	virtual void AddChildren(const Widget &w,CxxFile &f,const std::string &instance,const WriterBase &writer_for_subw, const Widget &widget_for_subw) const;
 	virtual bool NeedExplicitCtor(const Widget &w) const
 	{  return false; }
 	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
 	{  f.FunctionArg(); }
+private:
+	static std::string AttachOptions(bool resize,bool shrink);
 };
 
 static Gtk_Paned Gtk_Paned;
@@ -41,7 +43,7 @@ const std::string Gtk_Paned::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Paned::IncludeName(const Widget &w) const
-{  return "gtk--/paned.h";
+{  return Configuration.GtkmmIncludePath()+"paned.h";
 }
 
 Gtk_Paned::Gtk_Paned()
@@ -51,30 +53,40 @@ Gtk_Paned::Gtk_Paned()
 
 void Gtk_Paned::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   int handle_size(w.getInt("handle_size",10));
-   int gutter_size(w.getInt("gutter_size",6));
-   f.Statement() << instance << "set_handle_size(" << handle_size << ')';
-   f.Statement() << instance << "set_gutter_size(" << gutter_size << ')';
-   int position(w.getInt("position"));
-   f.Statement() << instance << "set_position(" << position << ')';
+   if (GTKMM1) WriteIntProperty(w,f,instance, "handle_size");
+   if (GTKMM1 && Configuration.gtk_version<Pkg_Version(1,3,0))
+      WriteIntProperty(w,f,instance, "gutter_size");
+   WriteIntProperty(w,f,instance, "position");
 }
 
-void Gtk_Paned::AddChildren(const Widget &w,CxxFile &f,const std::string &instance) const
+std::string Gtk_Paned::AttachOptions(bool resize,bool shrink)
+{  std::string attach_options="0";
+   if (resize) attach_options+="|Gtk::EXPAND";
+   if (shrink) attach_options+="|Gtk::SHRINK";
+   if (attach_options!="0") return attach_options.substr(2);
+   else return "Gtk::AttachOptions(0)";
+}
+
+void Gtk_Paned::AddChildren(const Widget &w,CxxFile &f,const std::string &instance,const WriterBase &writer_for_subw, const Widget &widget_for_subw) const
 {  Widget::const_iterator i=w.begin();
    if (i!=w.end() && (*i).Class()!="Placeholder")
    {  const ChildParamList ch((*i).get_Child_params());
-      bool resize(ch.getBool("resize",false));
-      bool shrink(ch.getBool("shrink",true));
-      f.Statement() << instance << "pack1(" << Reference(*i) << ", " 
-      		<< PRINT_BOOL(resize) << ", " << PRINT_BOOL(shrink) << ')';
+      bool resize(ch.getBoolProperty("resize",false));
+      bool shrink(ch.getBoolProperty("shrink",true));
+      f.Statement() << instance << "pack1(" << Reference(*i) << ", ";
+      if (GTKMM1) f << PRINT_BOOL(resize) << ", " << PRINT_BOOL(shrink);
+      else f << AttachOptions(resize,shrink);
+      f << ')';
    }
    ++i;
    if (i!=w.end() && (*i).Class()!="Placeholder")
    {  const ChildParamList ch((*i).get_Child_params());
-      bool resize(ch.getBool("resize",true));
-      bool shrink(ch.getBool("shrink",true));
-      f.Statement() << instance << "pack2(" << Reference(*i) << ", " 
-      		<< PRINT_BOOL(resize) << ", " << PRINT_BOOL(shrink) << ')';
+      bool resize(ch.getBoolProperty("resize",true));
+      bool shrink(ch.getBoolProperty("shrink",true));
+      f.Statement() << instance << "pack2(" << Reference(*i) << ", ";
+      if (GTKMM1) f << PRINT_BOOL(resize) << ", " << PRINT_BOOL(shrink);
+      else f << AttachOptions(resize,shrink);
+      f << ')';
    }
    ++i;
    if (i!=w.end()) 
