@@ -1,4 +1,4 @@
-// $Id: ruler.cc,v 1.18 2001/10/11 14:07:24 christof Exp $
+// $Id: ruler.cc,v 1.22 2002/06/15 13:22:14 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -40,7 +40,7 @@ const std::string Gtk_Ruler::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Ruler::IncludeName(const Widget &w) const
-{  return "gtk--/ruler.h";
+{  return Configuration.GtkmmIncludePath()+"ruler.h";
 }
 
 Gtk_Ruler::Gtk_Ruler()
@@ -50,13 +50,12 @@ Gtk_Ruler::Gtk_Ruler()
 
 void Gtk_Ruler::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   std::string metric=w.getString("metric","GTK_PIXELS");
-   f.Statement() << instance << "set_metric(" << metric << ')';
+   WriteEnumPropertyNS(w,f,instance, "metric");
 
-   float lower=w.getFloat("lower",0);
-   float upper=w.getFloat("upper",10);
-   float position=w.getFloat("position",5);
-   float max_size=w.getFloat("max_size",10);
+   float lower=w.getFloatProperty("lower",0);
+   float upper=w.getFloatProperty("upper",10);
+   float position=w.getFloatProperty("position",5);
+   float max_size=w.getFloatProperty("max_size",10);
    f.Statement() << instance << "set_range(" << lower << ", " << upper << ", "
      << position << ", " << max_size << ')';
 }
