@@ -1,4 +1,4 @@
-// $Id: scrollbar.cc,v 1.21 2001/10/11 14:07:24 christof Exp $
+// $Id: scrollbar.cc,v 1.22 2002/05/14 08:25:45 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -36,7 +36,7 @@ const std::string Gtk_ScrollBar::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_ScrollBar::IncludeName(const Widget &w) const
-{  return "gtk--/scrollbar.h";
+{  return Configuration.GtkmmIncludePath()+"scrollbar.h";
 }
 
 Gtk_ScrollBar::Gtk_ScrollBar()
