@@ -1,4 +1,4 @@
-// $Id: table.cc,v 1.27 2001/10/11 14:07:25 christof Exp $
+// $Id: table.cc,v 1.33 2002/12/19 09:01:18 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
@@ -19,6 +19,7 @@
  */
 
 #include "container.hh"
+#include "stringtok.h"
 
 class Gtk_Table : public Gtk_Container
 {public:
@@ -40,7 +41,7 @@ const std::string Gtk_Table::TypeName(const Widget &w) const
 }
 
 const std::string Gtk_Table::IncludeName(const Widget &w) const
-{  return "gtk--/table.h";
+{  return Configuration.GtkmmIncludePath()+"table.h";
 }
 
 Gtk_Table::Gtk_Table()
@@ -48,30 +49,54 @@ Gtk_Table::Gtk_Table()
 }
 
 void Gtk_Table::ConstructionArgs(const Widget &w, CxxFile &f) const
-{  f.FunctionArg() << w.getInt("rows",2);
-   f.FunctionArg() << w.getInt("columns",2);
-   f.FunctionArg() << PRINT_BOOL(w.getBool("homogeneous",true));
+{  f.FunctionArg() << w.getIntProperty("rows",2);
+   f.FunctionArg() << w.getIntProperty("columns",2);
+   f.FunctionArg() << PRINT_BOOL(w.getBoolProperty("homogeneous",true));
+}
+
+std::string getAttachOptions(const ChildParamList& ch, const std::string which)
+{  std::string options = "0";
+
+   // glade2 style
+   if (ch.hasProperty(which+"_options"))
+   {  std::list<std::string> list;
+
+      stringtok(list, ch.getProperty(which+"_options"), "|");
+      for (std::list<std::string>::iterator i = list.begin();
+           i != list.end();
+           ++i)
+         if (*i == "fill") options += "|GTK_FILL";
+         else if (*i == "expand") options += "|GTK_EXPAND";
+         else if (*i == "shrink") options += "|GTK_SHRINK";
+   }
+   else // glade1 style
+   {  if (ch.getBoolProperty(which+"expand",true)) options+="|GTK_EXPAND";
+      if (ch.getBoolProperty(which+"shrink",false)) options+="|GTK_SHRINK";
+      if (ch.getBoolProperty(which+"fill",true)) options+="|GTK_FILL";
+   }
+
+   // strip leading '0|'
+   if (options.size()>1)
+      options=options.substr(2);
+   else
+      if (GTKMM2) options="Gtk::AttachOptions()";
+
+   return options;
 }
 
 void Gtk_Table::AddChild(const Widget &w,CxxFile &f,const std::string &instance) const
 {  const ChildParamList ch=w.get_Child_params();
-   int left_attach=ch.getInt("left_attach",-1);
-   int right_attach=ch.getInt("right_attach",-1);
-   int top_attach=ch.getInt("top_attach",-1);
-   int bottom_attach=ch.getInt("bottom_attach",-1);
-   std::string xoptions("0"),yoptions("0");
-   if (ch.getBool("xexpand",true)) xoptions+="|GTK_EXPAND";
-   if (ch.getBool("xshrink",false)) xoptions+="|GTK_SHRINK";
-   if (ch.getBool("xfill",true)) xoptions+="|GTK_FILL";
-   if (ch.getBool("yexpand",true)) yoptions+="|GTK_EXPAND";
-   if (ch.getBool("yshrink",false)) yoptions+="|GTK_SHRINK";
-   if (ch.getBool("yfill",true)) yoptions+="|GTK_FILL";
-   int xpad=ch.getInt("xpad",0);
-   int ypad=ch.getInt("ypad",0);
-   
-   // strip leading '0|'
-   if (xoptions.size()>1) xoptions=std::string(xoptions.begin()+2,xoptions.end());
-   if (yoptions.size()>1) yoptions=std::string(yoptions.begin()+2,yoptions.end());
+   int left_attach=ch.getIntProperty("left_attach",-1);
+   int right_attach=ch.getIntProperty("right_attach",-1);
+   int top_attach=ch.getIntProperty("top_attach",-1);
+   int bottom_attach=ch.getIntProperty("bottom_attach",-1);
+
+   std::string xoptions = getAttachOptions(ch, "x");
+   std::string yoptions = getAttachOptions(ch, "y");
+
+   int xpad=ch.getIntProperty("xpad",ch.getIntProperty("x_padding",0));
+   int ypad=ch.getIntProperty("ypad",ch.getIntProperty("y_padding",0));
+
    if (xoptions=="GTK_FILL|GTK_EXPAND" 
        && yoptions=="GTK_FILL|GTK_EXPAND" && !xpad && !ypad)
          f.Statement() << instance << "attach(" << Reference(w) << ", "
@@ -81,16 +106,13 @@ void Gtk_Table::AddChild(const Widget &w,CxxFile &f,const std::string &instance)
       f.Statement() << instance << "attach(" 
         << Reference(w) << ", " << left_attach << ", " << right_attach 
         << ", " << top_attach << ", " << bottom_attach << ", " 
-        << xoptions << ", " << yoptions << ", " << xpad << ", " << ypad << ')';
+        << Gtkmm2Namespace(xoptions) << ", " << Gtkmm2Namespace(yoptions)
+        << ", " << xpad << ", " << ypad << ')';
 }
 
 void Gtk_Table::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
 {  Parent::Configure(w,f,instance);
-   int row_spacing=w.getInt("row_spacing");
-   if (row_spacing)
-      f.Statement() << instance << "set_row_spacings(" << row_spacing << ')';
-   int column_spacing=w.getInt("column_spacing");
-   if (column_spacing)
-      f.Statement() << instance << "set_col_spacings(" << column_spacing << ')';
+   WriteIntProperty(w,f,instance, "row_spacing", false, "row_spacings");
+   WriteIntProperty(w,f,instance, "column_spacing", false, "col_spacings");
 }
 
