@@ -1,4 +1,4 @@
-// $Id: widget.cc,v 1.59 2003/06/16 14:08:17 christof Exp $
+// $Id: widget.cc,v 1.66 2004/06/22 15:25:23 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
  *
@@ -59,26 +59,30 @@ const std::string Gtk_Widget::SignalHandlerArgs(const Widget &w,const std::strin
    const std::string drag_context= GTKMM2
         ? "const Glib::RefPtr<Gdk::DragContext>& context"
    	: "GdkDragContext *context";
+   const std::string selection_data = GTKMM24
+        ? "Gtk::SelectionData &selection_data"
+        : "GtkSelectionData *selection_data";
    if (signal=="drag_begin" || signal=="drag_end" || signal=="drag_data_delete") 
    	return drag_context;
-   if (signal=="drag_data_get") return drag_context+",GtkSelectionData *selection_data,guint info,guint time";
+   if (signal=="drag_data_get") return drag_context+","+selection_data+",guint info,guint time";
    if (signal=="drag_leave") return drag_context+",guint time";
    if (signal=="drag_motion" || signal=="drag_drop") 
    	return drag_context+",gint x,gint y,guint time";
-   if (signal=="drag_data_received") 
-   	return drag_context+",gint x,gint y,GtkSelectionData*selection_data,guint info,guint time";
+   if (signal=="drag_data_received")
+   	return drag_context+",gint x,gint y,"+selection_data+",guint info,guint time";
    if (signal=="drop_enter_event") { rettype=bool_sig_ret; return "GdkEventDropEnter *ev"; }
    if (signal=="drop_leave_event") { rettype=bool_sig_ret; return "GdkEventDropLeave *ev"; }
    if (signal=="drop_data_available_event") { rettype=bool_sig_ret; return "GdkEventDropDataAvailable *ev"; }
    if (signal=="other_event") { rettype=bool_sig_ret; return "GdkEventOther *ev"; }
-   if (signal=="selection_received") return "GtkSelectionData *selection_data,guint time";
-   if (signal=="selection_get") return "GtkSelectionData *selection_data,guint info,guint time";
+   if (signal=="selection_received") return selection_data+",guint time";
+   if (signal=="selection_get") return selection_data+",guint info,guint time";
    if (signal=="client_event") { rettype=bool_sig_ret; return "GdkEventClient *ev"; }
    if (signal=="no_expose_event") { rettype=bool_sig_ret; return "GdkEventAny *ev"; }
    if (signal=="show" || signal=="grab_focus" || signal=="hide" 
    	|| signal=="destroy" || signal=="map" || signal=="unmap"
    	|| signal=="realize" || signal=="unrealize") return "";
    if (signal=="popup_menu") { rettype="bool"; return ""; }
+   if (signal=="visibility_notify_event") { rettype=bool_sig_ret; return "GdkEventVisibility *ev"; }
    scope="";
    return "";
 }
@@ -115,9 +119,13 @@ void Gtk_Widget::Configure(const Widget &w, CxxFile &f,const std::string &instan
 
    if (GTKMM1) WriteBoolProp_2Fun(w,f,instance, "can_focus", 
    		"unset_flags(GTK_CAN_FOCUS)", "set_flags(GTK_CAN_FOCUS)");
-   else WriteBoolProp_2Fun(w,f,instance, "can_focus", 
+   else 
+   {  WriteBoolProp_2Fun(w,f,instance, "can_focus", 
    		"unset_flags(Gtk::CAN_FOCUS)", "set_flags(Gtk::CAN_FOCUS)"); 
-
+      WriteBoolProp_2Fun(w,f,instance, "can_default", 
+   		"unset_flags(Gtk::CAN_DEFAULT)", "set_flags(Gtk::CAN_DEFAULT)"); 
+   }
+   
    if (w.getBoolProperty("has_focus",false))
    {  f.Statement() << instance << "grab_focus()";
    }
@@ -192,3 +200,13 @@ bool Gtk_Widget::isInternalMethod(const Widget &w,std::string &method,const std:
    return Parent::isInternalMethod(w,method,args,scope,is_signal);
 }
 
+bool Gtk_Widget::isProxySignal(const Widget &w,std::string &method,bool after)const
+{  if (after && method.size()>6 && method.substr(method.size()-6)=="_event")
+   {  std::string rettype,scope;
+      SignalHandlerArgs(w,method,rettype,scope);
+      if (scope==Gtk_Widget::TypeName(w))
+         std::cerr << "You really should connect with '!after' to " << w.Name() 
+      		<< "'s " << method << '\n';
+   }
+   return Parent::isProxySignal(w,method,after);
+}
